summaryrefslogtreecommitdiffstats
path: root/parts/outputviews/makeactionfilter.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
commit48d4a26399959121f33d2bc3bfe51c7827b654fc (patch)
tree5ae5e6e00d3ba330b7b8be9bc097154b6bc739e8 /parts/outputviews/makeactionfilter.cpp
parent7e701ace6592d09e1f2c0cf28c7d6d872d78f4f5 (diff)
downloadtdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.tar.gz
tdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.zip
TQt4 port kdevelop
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1236710 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'parts/outputviews/makeactionfilter.cpp')
-rw-r--r--parts/outputviews/makeactionfilter.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/parts/outputviews/makeactionfilter.cpp b/parts/outputviews/makeactionfilter.cpp
index 4edaae2b..ca3e843a 100644
--- a/parts/outputviews/makeactionfilter.cpp
+++ b/parts/outputviews/makeactionfilter.cpp
@@ -79,8 +79,8 @@ MakeActionFilter::ActionFormat* MakeActionFilter::actionFormats()
ActionFormat( i18n("built"), 1, 1, "\\[.+%\\] Built target (.*)" ), //cmake
ActionFormat( i18n("generating"), 1, 1, "\\[.+%\\] Generating (.*)" ), //cmake
- //moc and uic
- ActionFormat( i18n("generating"), 1, 2, "/(moc|uic)\\b.*\\s-o\\s([^\\s;]+)"),
+ //tqmoc and uic
+ ActionFormat( i18n("generating"), 1, 2, "/(tqmoc|uic)\\b.*\\s-o\\s([^\\s;]+)"),
ActionFormat( i18n("generating"), 1, 2, "^generating (.*)" ), //unsermake
ActionFormat( i18n("linking"), "libtool", "/bin/sh\\s.*libtool.*--mode=link\\s.*\\s-o\\s([^\\s;]+)", 1 ),
@@ -96,7 +96,7 @@ MakeActionFilter::ActionFormat* MakeActionFilter::actionFormats()
ActionFormat( i18n("compiling"), "dcopidl2cpp", "dcopidl2cpp (?:\\S* )*([^\\s;]+)", 1 ),
ActionFormat( i18n("installing"), 1, 1, "-- Installing (.*)" ), //cmake
- ActionFormat( TQString::null, TQString::null, 0, 0 )
+ ActionFormat( TQString(), TQString(), 0, 0 )
};
return formats;
@@ -167,11 +167,11 @@ void MakeActionFilter::test()
static TQValueList<TestItem> testItems = TQValueList<TestItem>()
<< TestItem( // simple qmake compile
- "g++ -c -pipe -Wall -W -O2 -DQT_NO_DEBUG -I/home/john/src/kde/qt-copy/mkspecs/default -I. "
+ "g++ -c -pipe -Wall -W -O2 -DTQT_NO_DEBUG -I/home/john/src/kde/qt-copy/mkspecs/default -I. "
"-I/home/john/src/kde/qt-copy/include -o test.o test.cpp",
"compiling", "g++", "test.cpp" )
<< TestItem( // simple qmake compile different option order
- "g++ -c -o test.o -pipe -Wall -W -O2 -DQT_NO_DEBUG -I/home/john/src/kde/qt-copy/mkspecs/default -I. "
+ "g++ -c -o test.o -pipe -Wall -W -O2 -DTQT_NO_DEBUG -I/home/john/src/kde/qt-copy/mkspecs/default -I. "
"-I/home/john/src/kde/qt-copy/include test.cpp",
"compiling", "g++", "test.cpp" )
<< TestItem( // simple qmake link
@@ -181,7 +181,7 @@ void MakeActionFilter::test()
<< TestItem( // automake 1.7, srcdir != builddir
"if /bin/sh ../../libtool --silent --mode=compile --tag=CXX g++ -DHAVE_CONFIG_H -I. "
"-I/home/john/src/kde/kdevelop/lib/interfaces -I../.. -I/usr/local/kde/include -I/home/john/src/kde/qt-copy/include "
- "-I/usr/X11R6/include -DQT_THREAD_SUPPORT -D_REENTRANT -Wnon-virtual-dtor -Wno-long-long -Wundef -Wall -pedantic -W "
+ "-I/usr/X11R6/include -DTQT_THREAD_SUPPORT -D_REENTRANT -Wnon-virtual-dtor -Wno-long-long -Wundef -Wall -pedantic -W "
"-Wpointer-arith -Wmissing-prototypes -Wwrite-strings -ansi -D_XOPEN_SOURCE=500 -D_BSD_SOURCE -Wcast-align -Wconversion "
"-Wchar-subscripts -fno-builtin -g3 -Wformat-security -Wmissing-format-attribute -fno-exceptions -fno-check-new "
"-fno-common -MT kdevcore.lo -MD -MP -MF \".deps/kdevcore.Tpo\" -c -o kdevcore.lo `test -f "
@@ -193,7 +193,7 @@ void MakeActionFilter::test()
"if g++ -DHAVE_CONFIG_H -I. -I/home/john/src/kde/kdevelop/src -I.. -I/home/john/src/kde/kdevelop/lib/interfaces "
"-I/home/john/src/kde/kdevelop/lib/sourceinfo -I/home/john/src/kde/kdevelop/lib/util -I/home/john/src/kde/kdevelop/lib "
"-I/home/john/src/kde/kdevelop/lib/qextmdi/include -I/home/john/src/kde/kdevelop/lib/structure -I/usr/local/kde/include "
- "-I/home/john/src/kde/qt-copy/include -I/usr/X11R6/include -DQT_THREAD_SUPPORT -D_REENTRANT -Wnon-virtual-dtor "
+ "-I/home/john/src/kde/qt-copy/include -I/usr/X11R6/include -DTQT_THREAD_SUPPORT -D_REENTRANT -Wnon-virtual-dtor "
"-Wno-long-long -Wundef -Wall -pedantic -W -Wpointer-arith -Wmissing-prototypes -Wwrite-strings -ansi "
"-D_XOPEN_SOURCE=500 -D_BSD_SOURCE -Wcast-align -Wconversion -Wchar-subscripts -fno-builtin -g3 -Wformat-security "
"-Wmissing-format-attribute -fno-exceptions -fno-check-new -fno-common -MT mainwindowideal.o -MD -MP -MF "
@@ -203,7 +203,7 @@ void MakeActionFilter::test()
"compiling", "g++", "mainwindowideal.cpp" )
<< TestItem( // automake and libtool compiling *.c files
"if /bin/sh ../../libtool --silent --tag=CC --mode=compile gcc -DHAVE_CONFIG_H -I. -I. -I../.. -I../../lib/interfaces"
- "-I../../lib/util -I/opt/kde3/include -I/usr/lib/qt3/include -I/usr/X11R6/include -DQT_THREAD_SUPPORT -D_REENTRANT "
+ "-I../../lib/util -I/opt/kde3/include -I/usr/lib/qt3/include -I/usr/X11R6/include -DTQT_THREAD_SUPPORT -D_REENTRANT "
"-std=iso9899:1990 -W -Wall -Wchar-subscripts -Wshadow -Wpointer-arith -Wmissing-prototypes -Wwrite-strings "
"-D_XOPEN_SOURCE=500 -D_BSD_SOURCE -g3 -fno-inline -Wformat-security -Wmissing-format-attribute -MT readtags.lo "
"-MD -MP -MF \".deps/readtags.Tpo\" -c -o readtags.lo readtags.c; then mv -f \".deps/readtags.Tpo\" "
@@ -213,7 +213,7 @@ void MakeActionFilter::test()
"source='makewidget.cpp' object='makewidget.lo' libtool=yes depfile='.deps/makewidget.Plo' "
"tmpdepfile='.deps/makewidget.TPlo' depmode=gcc3 /bin/sh ../../admin/depcomp /bin/sh ../../libtool --mode=compile "
"--tag=CXX g++ -DHAVE_CONFIG_H -I. -I. -I../.. -I../../lib/interfaces -I../../lib/util -I/opt/kde3/include "
- "-I/usr/lib/qt3/include -I/usr/X11R6/include -DQT_THREAD_SUPPORT -D_REENTRANT -Wnon-virtual-dtor -Wno-long-long -Wundef "
+ "-I/usr/lib/qt3/include -I/usr/X11R6/include -DTQT_THREAD_SUPPORT -D_REENTRANT -Wnon-virtual-dtor -Wno-long-long -Wundef "
"-Wall -pedantic -W -Wpointer-arith -Wmissing-prototypes -Wwrite-strings -ansi -D_XOPEN_SOURCE=500 -D_BSD_SOURCE "
"-Wcast-align -Wconversion -fno-builtin -g -O2 -g3 -O0 -fno-exceptions -fno-check-new -c -o makewidget.lo `test -f "
"'makewidget.cpp' || echo './'`makewidget.cpp",
@@ -233,7 +233,7 @@ void MakeActionFilter::test()
"-W -Wpointer-arith -Wwrite-strings -ansi -D_XOPEN_SOURCE=500 -D_BSD_SOURCE -Wcast-align -Wconversion -Wchar-subscripts "
"-fno-builtin -g3 -fno-exceptions -fno-check-new -fno-common -o libkfilereplacepart.la.closure libkfilereplacepart_la_closure.lo "
"-module -no-undefined -L/usr/X11R6/lib -L/usr/lib/qt3/lib -L/opt/kde3/lib -version-info 1:0:0 kfilereplacepart.lo kfilereplacedoc.lo "
- "kfilereplaceview.lo kaboutkfilereplace.lo kaddstringdlg.lo kconfirmdlg.lo kernel.lo kexpression.lo kfilereplacepref.lo "
+ "kfilereplaceview.lo kaboutkfiletqreplace.lo kaddstringdlg.lo kconfirmdlg.lo kernel.lo kexpression.lo kfilereplacepref.lo "
"klistviewstring.lo knewprojectdlg.lo koptionsdlg.lo kresultview.lo filelib.lo knewprojectdlgs.lo -lkio -lkparts -lkhtml",
"linking", "libtool", "libkfilereplacepart.la.closure")
<< TestItem( //libtool, linking 3
@@ -241,13 +241,13 @@ void MakeActionFilter::test()
"-W -Wpointer-arith -Wwrite-strings -ansi -D_XOPEN_SOURCE=500 -D_BSD_SOURCE -Wcast-align -Wconversion -Wchar-subscripts "
"-fno-builtin -g3 -fno-exceptions -fno-check-new -fno-common -o libkfilereplacepart.la -rpath /opt/kde3/lib/kde3 "
"-module -no-undefined -L/usr/X11R6/lib -L/usr/lib/qt3/lib -L/opt/kde3/lib -version-info 1:0:0 kfilereplacepart.lo "
- "kfilereplacedoc.lo kfilereplaceview.lo kaboutkfilereplace.lo kaddstringdlg.lo kconfirmdlg.lo kernel.lo kexpression.lo "
+ "kfilereplacedoc.lo kfilereplaceview.lo kaboutkfiletqreplace.lo kaddstringdlg.lo kconfirmdlg.lo kernel.lo kexpression.lo "
"kfilereplacepref.lo klistviewstring.lo knewprojectdlg.lo koptionsdlg.lo kresultview.lo filelib.lo knewprojectdlgs.lo -lkio -lkparts -lkhtml",
"linking", "libtool", "libkfilereplacepart.la")
<< TestItem( //automake, builddir!=srcdir, libtool=no, compiling
" g++ -DHAVE_CONFIG_H -I. -I/home/andris/cvs-developement/head/quanta/quanta/project "
"-I../.. -I/home/andris/cvs-developement/head/quanta/quanta/dialogs -I/opt/kde3/include -I/usr/lib/qt3/include -I/usr/X11R6/include "
- "-I../../quanta/dialogs -DQT_THREAD_SUPPORT -D_REENTRANT -DKOMMANDER -DDESIGNER -DQT_NO_SQL -DHAVE_KDE -Wnon-virtual-dtor "
+ "-I../../quanta/dialogs -DTQT_THREAD_SUPPORT -D_REENTRANT -DKOMMANDER -DDESIGNER -DTQT_NO_SQL -DHAVE_KDE -Wnon-virtual-dtor "
"-Wno-long-long -Wundef -Wall -pedantic -W -Wpointer-arith -Wmissing-prototypes -Wwrite-strings -ansi -D_XOPEN_SOURCE=500 -D_BSD_SOURCE "
"-Wcast-align -Wconversion -Wchar-subscripts -fno-builtin -g3 -DKDE_NO_COMPAT -fno-exceptions -fno-check-new -fno-common -c -o project.o "
"`test -f '/home/andris/cvs-developement/head/quanta/quanta/project/project.cpp' || "
@@ -272,14 +272,14 @@ void MakeActionFilter::test()
"quanta_init.cpp; "
"then mv -f \".deps/quanta_init.Tpo\" \".deps/quanta_init.Po\"; else rm -f \".deps/quanta_init.Tpo\"; "
"exit 1; fi",
- "compiling", "g++", "quanta_init.cpp")
+ "compiling", "g++", "tquanta_init.cpp")
<< TestItem( //libtool, automake 1.8, file with full path
"if g++ -DHAVE_CONFIG_H -I. -I/home/andris/ "
"-DBUILD_KAFKAPART -MT quanta_init.o -MD -MP -MF \".deps/quanta_init.Tpo\" -c -o quanta_init.o "
"/home/andris/quanta_init.cpp; "
"then mv -f \".deps/quanta_init.Tpo\" \".deps/quanta_init.Po\"; else rm -f \".deps/quanta_init.Tpo\"; "
"exit 1; fi",
- "compiling", "g++", "quanta_init.cpp")
+ "compiling", "g++", "tquanta_init.cpp")
;
TQValueList<TestItem>::const_iterator it = testItems.begin();